@@ -1,8 +1,8 @@
-# 213 "pcb-menu.res"
+# 219 "pcb-menu.res"
 char *s = N_(" Center");
 # 150 "pcb-menu.res"
 char *s = N_(" Change text on layout");
-# 215 "pcb-menu.res"
+# 221 "pcb-menu.res"
 char *s = N_(" Crosshair");
 # 155 "pcb-menu.res"
 char *s = N_(" CurrentLayer");
@@ -14,7 +14,7 @@ char *s = N_(" Edit name of layout");
 char *s = N_(" Element");
 # 154 "pcb-menu.res"
 char *s = N_(" Layout");
-# 214 "pcb-menu.res"
+# 220 "pcb-menu.res"
 char *s = N_(" Mark");
 # 47 "pcb-menu.res"
 char *s = N_(" a single element");
@@ -22,21 +22,21 @@ char *s = N_(" a single element");
 char *s = N_(" all elements");
 # 49 "pcb-menu.res"
 char *s = N_(" unused pins");
-# 293 "pcb-menu.res"
+# 299 "pcb-menu.res"
 char *s = N_("#1");
-# 294 "pcb-menu.res"
+# 300 "pcb-menu.res"
 char *s = N_("#2");
-# 295 "pcb-menu.res"
+# 301 "pcb-menu.res"
 char *s = N_("#3");
-# 296 "pcb-menu.res"
+# 302 "pcb-menu.res"
 char *s = N_("#4");
-# 297 "pcb-menu.res"
+# 303 "pcb-menu.res"
 char *s = N_("#5");
-# 191 "pcb-menu.res"
+# 197 "pcb-menu.res"
 char *s = N_("'All-direction' lines");
-# 191 "pcb-menu.res"
+# 197 "pcb-menu.res"
 char *s = N_(".");
-# 419 "pcb-menu.res"
+# 425 "pcb-menu.res"
 char *s = N_("/");
 # 108 "pcb-menu.res"
 char *s = N_("0.01 mm");
@@ -64,287 +64,295 @@ char *s = N_("25 mil");
 char *s = N_("5 mil");
 # 105 "pcb-menu.res"
 char *s = N_("50 mil");
-# 185 "pcb-menu.res"
-char *s = N_(":");
 # 191 "pcb-menu.res"
+char *s = N_(":");
+# 197 "pcb-menu.res"
 char *s = N_("<Key>.");
-# 419 "pcb-menu.res"
-char *s = N_("<Key>/");
-# 185 "pcb-menu.res"
-char *s = N_("<Key>:");
-# 321 "pcb-menu.res"
-char *s = N_("<Key>=");
-# 342 "pcb-menu.res"
-char *s = N_("<Key>BackSpace");
-# 242 "pcb-menu.res"
-char *s = N_("<Key>Delete");
 # 425 "pcb-menu.res"
+char *s = N_("<Key>/");
+# 191 "pcb-menu.res"
+char *s = N_("<Key>:");
+# 327 "pcb-menu.res"
+char *s = N_("<Key>=");
+# 348 "pcb-menu.res"
+char *s = N_("<Key>BackSpace");
+# 248 "pcb-menu.res"
+char *s = N_("<Key>Delete");
+# 431 "pcb-menu.res"
 char *s = N_("<Key>Down");
-# 432 "pcb-menu.res"
+# 438 "pcb-menu.res"
 char *s = N_("<Key>Enter");
-# 183 "pcb-menu.res"
+# 189 "pcb-menu.res"
 char *s = N_("<Key>Escape");
-# 167 "pcb-menu.res"
+# 173 "pcb-menu.res"
 char *s = N_("<Key>F1");
-# 177 "pcb-menu.res"
+# 183 "pcb-menu.res"
 char *s = N_("<Key>F10");
-# 178 "pcb-menu.res"
+# 184 "pcb-menu.res"
 char *s = N_("<Key>F11");
-# 182 "pcb-menu.res"
+# 188 "pcb-menu.res"
 char *s = N_("<Key>F12");
-# 168 "pcb-menu.res"
-char *s = N_("<Key>F2");
-# 169 "pcb-menu.res"
-char *s = N_("<Key>F3");
-# 170 "pcb-menu.res"
-char *s = N_("<Key>F4");
-# 171 "pcb-menu.res"
-char *s = N_("<Key>F5");
-# 172 "pcb-menu.res"
-char *s = N_("<Key>F6");
 # 174 "pcb-menu.res"
-char *s = N_("<Key>F7");
+char *s = N_("<Key>F2");
 # 175 "pcb-menu.res"
-char *s = N_("<Key>F8");
+char *s = N_("<Key>F3");
 # 176 "pcb-menu.res"
+char *s = N_("<Key>F4");
+# 177 "pcb-menu.res"
+char *s = N_("<Key>F5");
+# 178 "pcb-menu.res"
+char *s = N_("<Key>F6");
+# 180 "pcb-menu.res"
+char *s = N_("<Key>F7");
+# 181 "pcb-menu.res"
+char *s = N_("<Key>F8");
+# 182 "pcb-menu.res"
 char *s = N_("<Key>F9");
-# 179 "pcb-menu.res"
+# 185 "pcb-menu.res"
 char *s = N_("<Key>Insert");
-# 426 "pcb-menu.res"
+# 432 "pcb-menu.res"
 char *s = N_("<Key>Left");
-# 427 "pcb-menu.res"
+# 433 "pcb-menu.res"
 char *s = N_("<Key>Right");
 # 56 "pcb-menu.res"
 char *s = N_("<Key>Tab");
-# 424 "pcb-menu.res"
+# 430 "pcb-menu.res"
 char *s = N_("<Key>Up");
-# 421 "pcb-menu.res"
+# 427 "pcb-menu.res"
 char *s = N_("<Key>[");
-# 422 "pcb-menu.res"
+# 428 "pcb-menu.res"
 char *s = N_("<Key>]");
 # 83 "pcb-menu.res"
 char *s = N_("<Key>`");
-# 379 "pcb-menu.res"
+# 385 "pcb-menu.res"
 char *s = N_("<Key>a");
-# 380 "pcb-menu.res"
+# 386 "pcb-menu.res"
 char *s = N_("<Key>b");
 # 60 "pcb-menu.res"
 char *s = N_("<Key>c");
-# 209 "pcb-menu.res"
+# 215 "pcb-menu.res"
 char *s = N_("<Key>d");
-# 308 "pcb-menu.res"
+# 314 "pcb-menu.res"
 char *s = N_("<Key>e");
-# 381 "pcb-menu.res"
+# 387 "pcb-menu.res"
 char *s = N_("<Key>f");
 # 116 "pcb-menu.res"
 char *s = N_("<Key>g");
-# 382 "pcb-menu.res"
+# 388 "pcb-menu.res"
 char *s = N_("<Key>h");
-# 385 "pcb-menu.res"
-char *s = N_("<Key>j");
-# 387 "pcb-menu.res"
-char *s = N_("<Key>k");
 # 391 "pcb-menu.res"
-char *s = N_("<Key>l");
+char *s = N_("<Key>j");
 # 393 "pcb-menu.res"
+char *s = N_("<Key>k");
+# 397 "pcb-menu.res"
+char *s = N_("<Key>l");
+# 399 "pcb-menu.res"
 char *s = N_("<Key>m");
 # 150 "pcb-menu.res"
 char *s = N_("<Key>n");
-# 307 "pcb-menu.res"
+# 313 "pcb-menu.res"
 char *s = N_("<Key>o");
-# 403 "pcb-menu.res"
+# 409 "pcb-menu.res"
 char *s = N_("<Key>p");
-# 405 "pcb-menu.res"
+# 411 "pcb-menu.res"
 char *s = N_("<Key>q");
-# 340 "pcb-menu.res"
+# 346 "pcb-menu.res"
 char *s = N_("<Key>r");
-# 406 "pcb-menu.res"
+# 412 "pcb-menu.res"
 char *s = N_("<Key>s");
-# 420 "pcb-menu.res"
+# 426 "pcb-menu.res"
 char *s = N_("<Key>space");
-# 410 "pcb-menu.res"
+# 416 "pcb-menu.res"
 char *s = N_("<Key>t");
 # 134 "pcb-menu.res"
 char *s = N_("<Key>u");
 # 82 "pcb-menu.res"
 char *s = N_("<Key>v");
-# 417 "pcb-menu.res"
+# 423 "pcb-menu.res"
 char *s = N_("<Key>w");
-# 323 "pcb-menu.res"
+# 329 "pcb-menu.res"
 char *s = N_("<Key>y");
 # 79 "pcb-menu.res"
 char *s = N_("<Key>z");
-# 204 "pcb-menu.res"
+# 210 "pcb-menu.res"
 char *s = N_("<Key>|");
-# 321 "pcb-menu.res"
+# 327 "pcb-menu.res"
 char *s = N_("=");
-# 379 "pcb-menu.res"
+# 385 "pcb-menu.res"
 char *s = N_("A");
 # 32 "pcb-menu.res"
 char *s = N_("About...");
-# 417 "pcb-menu.res"
+# 423 "pcb-menu.res"
 char *s = N_("Add All Rats");
 # 128 "pcb-menu.res"
 char *s = N_("Add new layer");
-# 416 "pcb-menu.res"
+# 422 "pcb-menu.res"
 char *s = N_("AddRats Selected");
-# 396 "pcb-menu.res"
+# 402 "pcb-menu.res"
 char *s = N_("AddRats to selected pins");
-# 327 "pcb-menu.res"
+# 333 "pcb-menu.res"
 char *s = N_("All");
-# 231 "pcb-menu.res"
+# 237 "pcb-menu.res"
 char *s = N_("All objects");
-# 409 "pcb-menu.res"
-char *s = N_("Alt Shift<Key>s");
 # 415 "pcb-menu.res"
+char *s = N_("Alt Shift<Key>s");
+# 421 "pcb-menu.res"
 char *s = N_("Alt Shift<Key>v");
 # 147 "pcb-menu.res"
 char *s = N_("Alt-A");
-# 246 "pcb-menu.res"
+# 252 "pcb-menu.res"
 char *s = N_("Alt-R");
-# 408 "pcb-menu.res"
-char *s = N_("Alt-S");
-# 409 "pcb-menu.res"
-char *s = N_("Alt-Shift-S");
-# 415 "pcb-menu.res"
-char *s = N_("Alt-Shift-V");
 # 414 "pcb-menu.res"
+char *s = N_("Alt-S");
+# 415 "pcb-menu.res"
+char *s = N_("Alt-Shift-S");
+# 421 "pcb-menu.res"
+char *s = N_("Alt-Shift-V");
+# 420 "pcb-menu.res"
 char *s = N_("Alt-V");
-# 418 "pcb-menu.res"
+# 424 "pcb-menu.res"
 char *s = N_("Alt-Z");
 # 147 "pcb-menu.res"
 char *s = N_("Alt<Key>a");
-# 246 "pcb-menu.res"
+# 252 "pcb-menu.res"
 char *s = N_("Alt<Key>r");
-# 408 "pcb-menu.res"
-char *s = N_("Alt<Key>s");
 # 414 "pcb-menu.res"
-char *s = N_("Alt<Key>v");
-# 418 "pcb-menu.res"
-char *s = N_("Alt<Key>z");
-# 333 "pcb-menu.res"
-char *s = N_("Apply vendor drill mapping");
-# 282 "pcb-menu.res"
-char *s = N_("Arbitrarily Rotate Buffer");
-# 169 "pcb-menu.res"
-char *s = N_("Arc");
+char *s = N_("Alt<Key>s");
 # 420 "pcb-menu.res"
+char *s = N_("Alt<Key>v");
+# 424 "pcb-menu.res"
+char *s = N_("Alt<Key>z");
+# 339 "pcb-menu.res"
+char *s = N_("Apply vendor drill mapping");
+# 288 "pcb-menu.res"
+char *s = N_("Arbitrarily Rotate Buffer");
+# 175 "pcb-menu.res"
+char *s = N_("Arc");
+# 426 "pcb-menu.res"
 char *s = N_("Arrow");
-# 196 "pcb-menu.res"
+# 202 "pcb-menu.res"
 char *s = N_("Auto enforce DRC clearance");
-# 192 "pcb-menu.res"
+# 198 "pcb-menu.res"
 char *s = N_("Auto swap line start angle");
-# 315 "pcb-menu.res"
+# 321 "pcb-menu.res"
 char *s = N_("Auto-Optimize");
-# 238 "pcb-menu.res"
+# 244 "pcb-menu.res"
 char *s = N_("Auto-place selected elements");
-# 312 "pcb-menu.res"
+# 318 "pcb-menu.res"
 char *s = N_("Auto-route all rats");
-# 311 "pcb-menu.res"
+# 317 "pcb-menu.res"
 char *s = N_("Auto-route selected rats");
-# 200 "pcb-menu.res"
+# 206 "pcb-menu.res"
 char *s = N_("Auto-zero delta measurements");
-# 380 "pcb-menu.res"
+# 386 "pcb-menu.res"
 char *s = N_("B");
-# 342 "pcb-menu.res"
+# 348 "pcb-menu.res"
 char *s = N_("Backspace");
-# 436 "pcb-menu.res"
+# 442 "pcb-menu.res"
 char *s = N_("Board Layout");
 # 158 "pcb-menu.res"
 char *s = N_("Board Sizes");
-# 289 "pcb-menu.res"
+# 295 "pcb-menu.res"
 char *s = N_("Break buffer elements to pieces");
-# 174 "pcb-menu.res"
+# 180 "pcb-menu.res"
 char *s = N_("Buffer");
+# 167 "pcb-menu.res"
+char *s = N_("Buried from");
+# 168 "pcb-menu.res"
+char *s = N_("Buried to");
 # 60 "pcb-menu.res"
 char *s = N_("C");
 # 44 "pcb-menu.res"
 char *s = N_("Calibrate Printer...");
-# 183 "pcb-menu.res"
+# 189 "pcb-menu.res"
 char *s = N_("Cancel");
 # 60 "pcb-menu.res"
 char *s = N_("Center cursor");
-# 261 "pcb-menu.res"
-char *s = N_("Change drilling hole of selected objects");
-# 249 "pcb-menu.res"
-char *s = N_("Change size of selected objects");
 # 267 "pcb-menu.res"
+char *s = N_("Change drilling hole of selected objects");
+# 255 "pcb-menu.res"
+char *s = N_("Change size of selected objects");
+# 273 "pcb-menu.res"
 char *s = N_("Change square-flag of selected objects");
-# 408 "pcb-menu.res"
+# 414 "pcb-menu.res"
 char *s = N_("ChangeDrill +5 mil");
-# 409 "pcb-menu.res"
+# 415 "pcb-menu.res"
 char *s = N_("ChangeDrill -5 mil");
-# 384 "pcb-menu.res"
-char *s = N_("ChangeHole Object");
-# 385 "pcb-menu.res"
-char *s = N_("ChangeJoin Object");
-# 386 "pcb-menu.res"
-char *s = N_("ChangeJoin SelectedObject");
-# 402 "pcb-menu.res"
-char *s = N_("ChangeOctagon Object");
-# 406 "pcb-menu.res"
-char *s = N_("ChangeSize +");
-# 407 "pcb-menu.res"
-char *s = N_("ChangeSize -");
-# 405 "pcb-menu.res"
-char *s = N_("ChangeSquare Object");
-# 206 "pcb-menu.res"
-char *s = N_("Check polygons");
-# 387 "pcb-menu.res"
-char *s = N_("Clear Object +");
-# 388 "pcb-menu.res"
-char *s = N_("Clear Object -");
-# 389 "pcb-menu.res"
-char *s = N_("Clear Selected +");
 # 390 "pcb-menu.res"
+char *s = N_("ChangeHole Object");
+# 391 "pcb-menu.res"
+char *s = N_("ChangeJoin Object");
+# 392 "pcb-menu.res"
+char *s = N_("ChangeJoin SelectedObject");
+# 408 "pcb-menu.res"
+char *s = N_("ChangeOctagon Object");
+# 412 "pcb-menu.res"
+char *s = N_("ChangeSize +");
+# 413 "pcb-menu.res"
+char *s = N_("ChangeSize -");
+# 411 "pcb-menu.res"
+char *s = N_("ChangeSquare Object");
+# 212 "pcb-menu.res"
+char *s = N_("Check polygons");
+# 393 "pcb-menu.res"
+char *s = N_("Clear Object +");
+# 394 "pcb-menu.res"
+char *s = N_("Clear Object -");
+# 395 "pcb-menu.res"
+char *s = N_("Clear Selected +");
+# 396 "pcb-menu.res"
 char *s = N_("Clear Selected -");
-# 287 "pcb-menu.res"
+# 293 "pcb-menu.res"
 char *s = N_("Clear buffer");
 # 136 "pcb-menu.res"
 char *s = N_("Clear undo-buffer");
-# 432 "pcb-menu.res"
+# 438 "pcb-menu.res"
 char *s = N_("Click");
-# 185 "pcb-menu.res"
+# 191 "pcb-menu.res"
 char *s = N_("Command");
-# 288 "pcb-menu.res"
+# 294 "pcb-menu.res"
 char *s = N_("Convert buffer to element");
-# 243 "pcb-menu.res"
+# 249 "pcb-menu.res"
 char *s = N_("Convert selection to element");
-# 181 "pcb-menu.res"
+# 187 "pcb-menu.res"
 char *s = N_("Copy");
-# 273 "pcb-menu.res"
+# 279 "pcb-menu.res"
 char *s = N_("Copy selection to buffer");
-# 195 "pcb-menu.res"
+# 201 "pcb-menu.res"
 char *s = N_("Crosshair shows DRC clearance");
-# 194 "pcb-menu.res"
+# 200 "pcb-menu.res"
 char *s = N_("Crosshair snaps to pins and pads");
 # 59 "pcb-menu.res"
 char *s = N_("Ctrl Shift<Key>Tab");
-# 205 "pcb-menu.res"
+# 167 "pcb-menu.res"
+char *s = N_("Ctrl Shift<Key>f");
+# 211 "pcb-menu.res"
 char *s = N_("Ctrl Shift<Key>p");
+# 168 "pcb-menu.res"
+char *s = N_("Ctrl Shift<Key>t");
 # 143 "pcb-menu.res"
 char *s = N_("Ctrl-C");
-# 301 "pcb-menu.res"
+# 307 "pcb-menu.res"
 char *s = N_("Ctrl-F");
-# 384 "pcb-menu.res"
+# 390 "pcb-menu.res"
 char *s = N_("Ctrl-H");
-# 389 "pcb-menu.res"
+# 395 "pcb-menu.res"
 char *s = N_("Ctrl-K");
-# 394 "pcb-menu.res"
+# 400 "pcb-menu.res"
 char *s = N_("Ctrl-M");
 # 51 "pcb-menu.res"
 char *s = N_("Ctrl-N");
-# 402 "pcb-menu.res"
+# 408 "pcb-menu.res"
 char *s = N_("Ctrl-O");
-# 238 "pcb-menu.res"
+# 244 "pcb-menu.res"
 char *s = N_("Ctrl-P");
 # 53 "pcb-menu.res"
 char *s = N_("Ctrl-Q");
-# 337 "pcb-menu.res"
+# 343 "pcb-menu.res"
 char *s = N_("Ctrl-R");
 # 33 "pcb-menu.res"
 char *s = N_("Ctrl-S");
-# 205 "pcb-menu.res"
+# 211 "pcb-menu.res"
 char *s = N_("Ctrl-Shift-P");
 # 59 "pcb-menu.res"
 char *s = N_("Ctrl-Shift-Tab");
@@ -358,23 +366,23 @@ char *s = N_("Ctrl-X");
 char *s = N_("Ctrl<Key>Tab");
 # 143 "pcb-menu.res"
 char *s = N_("Ctrl<Key>c");
-# 301 "pcb-menu.res"
+# 307 "pcb-menu.res"
 char *s = N_("Ctrl<Key>f");
-# 384 "pcb-menu.res"
+# 390 "pcb-menu.res"
 char *s = N_("Ctrl<Key>h");
-# 389 "pcb-menu.res"
+# 395 "pcb-menu.res"
 char *s = N_("Ctrl<Key>k");
-# 394 "pcb-menu.res"
+# 400 "pcb-menu.res"
 char *s = N_("Ctrl<Key>m");
 # 51 "pcb-menu.res"
 char *s = N_("Ctrl<Key>n");
-# 402 "pcb-menu.res"
+# 408 "pcb-menu.res"
 char *s = N_("Ctrl<Key>o");
-# 238 "pcb-menu.res"
+# 244 "pcb-menu.res"
 char *s = N_("Ctrl<Key>p");
 # 53 "pcb-menu.res"
 char *s = N_("Ctrl<Key>q");
-# 337 "pcb-menu.res"
+# 343 "pcb-menu.res"
 char *s = N_("Ctrl<Key>r");
 # 33 "pcb-menu.res"
 char *s = N_("Ctrl<Key>s");
@@ -384,33 +392,33 @@ char *s = N_("Ctrl<Key>v");
 char *s = N_("Ctrl<Key>x");
 # 124 "pcb-menu.res"
 char *s = N_("Current Layer");
-# 275 "pcb-menu.res"
+# 281 "pcb-menu.res"
 char *s = N_("Cut selection to buffer");
-# 419 "pcb-menu.res"
+# 425 "pcb-menu.res"
 char *s = N_("Cycle Clip");
-# 209 "pcb-menu.res"
+# 215 "pcb-menu.res"
 char *s = N_("D");
-# 316 "pcb-menu.res"
+# 322 "pcb-menu.res"
 char *s = N_("Debumpify");
-# 242 "pcb-menu.res"
+# 248 "pcb-menu.res"
 char *s = N_("Delete");
 # 127 "pcb-menu.res"
 char *s = N_("Delete current layer");
-# 242 "pcb-menu.res"
+# 248 "pcb-menu.res"
 char *s = N_("Delete selected objects");
 # 64 "pcb-menu.res"
 char *s = N_("Description");
-# 331 "pcb-menu.res"
+# 337 "pcb-menu.res"
 char *s = N_("Design Rule Checker");
-# 239 "pcb-menu.res"
+# 245 "pcb-menu.res"
 char *s = N_("Disperse all elements");
 # 96 "pcb-menu.res"
 char *s = N_("Display grid");
 # 63 "pcb-menu.res"
 char *s = N_("Displayed element-name...");
-# 429 "pcb-menu.res"
+# 435 "pcb-menu.res"
 char *s = N_("Down");
-# 308 "pcb-menu.res"
+# 314 "pcb-menu.res"
 char *s = N_("E");
 # 153 "pcb-menu.res"
 char *s = N_("Edit Attributes...");
@@ -418,107 +426,107 @@ char *s = N_("Edit Attributes...");
 char *s = N_("Edit Layer Groups");
 # 149 "pcb-menu.res"
 char *s = N_("Edit Names...");
-# 189 "pcb-menu.res"
+# 195 "pcb-menu.res"
 char *s = N_("Edit layer groupings");
 # 162 "pcb-menu.res"
 char *s = N_("Edit...");
-# 268 "pcb-menu.res"
+# 274 "pcb-menu.res"
 char *s = N_("Elements");
-# 210 "pcb-menu.res"
+# 216 "pcb-menu.res"
 char *s = N_("Enable vendor drill mapping");
-# 432 "pcb-menu.res"
+# 438 "pcb-menu.res"
 char *s = N_("Enter");
-# 308 "pcb-menu.res"
+# 314 "pcb-menu.res"
 char *s = N_("Erase rats-nest");
-# 309 "pcb-menu.res"
+# 315 "pcb-menu.res"
 char *s = N_("Erase selected rats");
-# 183 "pcb-menu.res"
+# 189 "pcb-menu.res"
 char *s = N_("Esc");
 # 43 "pcb-menu.res"
 char *s = N_("Export layout...");
-# 381 "pcb-menu.res"
+# 387 "pcb-menu.res"
 char *s = N_("F");
-# 167 "pcb-menu.res"
+# 173 "pcb-menu.res"
 char *s = N_("F1");
-# 177 "pcb-menu.res"
+# 183 "pcb-menu.res"
 char *s = N_("F10");
-# 178 "pcb-menu.res"
+# 184 "pcb-menu.res"
 char *s = N_("F11");
-# 182 "pcb-menu.res"
+# 188 "pcb-menu.res"
 char *s = N_("F12");
-# 168 "pcb-menu.res"
-char *s = N_("F2");
-# 169 "pcb-menu.res"
-char *s = N_("F3");
-# 170 "pcb-menu.res"
-char *s = N_("F4");
-# 171 "pcb-menu.res"
-char *s = N_("F5");
-# 172 "pcb-menu.res"
-char *s = N_("F6");
 # 174 "pcb-menu.res"
-char *s = N_("F7");
+char *s = N_("F2");
 # 175 "pcb-menu.res"
-char *s = N_("F8");
+char *s = N_("F3");
 # 176 "pcb-menu.res"
+char *s = N_("F4");
+# 177 "pcb-menu.res"
+char *s = N_("F5");
+# 178 "pcb-menu.res"
+char *s = N_("F6");
+# 180 "pcb-menu.res"
+char *s = N_("F7");
+# 181 "pcb-menu.res"
+char *s = N_("F8");
+# 182 "pcb-menu.res"
 char *s = N_("F9");
-# 381 "pcb-menu.res"
+# 387 "pcb-menu.res"
 char *s = N_("Find Connections");
-# 380 "pcb-menu.res"
+# 386 "pcb-menu.res"
 char *s = N_("Flip Object");
 # 57 "pcb-menu.res"
 char *s = N_("Flip left/right");
 # 56 "pcb-menu.res"
 char *s = N_("Flip up/down");
-# 326 "pcb-menu.res"
+# 332 "pcb-menu.res"
 char *s = N_("Found");
 # 116 "pcb-menu.res"
 char *s = N_("G");
-# 338 "pcb-menu.res"
+# 344 "pcb-menu.res"
 char *s = N_("Generate drill summary");
-# 337 "pcb-menu.res"
+# 343 "pcb-menu.res"
 char *s = N_("Generate object report");
-# 324 "pcb-menu.res"
+# 330 "pcb-menu.res"
 char *s = N_("Global Puller");
 # 116 "pcb-menu.res"
 char *s = N_("Grid +");
 # 115 "pcb-menu.res"
 char *s = N_("Grid -");
-# 382 "pcb-menu.res"
+# 388 "pcb-menu.res"
 char *s = N_("H");
 # 69 "pcb-menu.res"
 char *s = N_("Hide Names");
 # 36 "pcb-menu.res"
 char *s = N_("Import Schematics");
-# 211 "pcb-menu.res"
+# 217 "pcb-menu.res"
 char *s = N_("Import Settings");
-# 179 "pcb-menu.res"
+# 185 "pcb-menu.res"
 char *s = N_("Insert");
-# 179 "pcb-menu.res"
+# 185 "pcb-menu.res"
 char *s = N_("Insert Point");
-# 385 "pcb-menu.res"
+# 391 "pcb-menu.res"
 char *s = N_("J");
-# 387 "pcb-menu.res"
+# 393 "pcb-menu.res"
 char *s = N_("K");
-# 341 "pcb-menu.res"
+# 347 "pcb-menu.res"
 char *s = N_("Key Bindings");
-# 391 "pcb-menu.res"
+# 397 "pcb-menu.res"
 char *s = N_("L");
-# 188 "pcb-menu.res"
+# 194 "pcb-menu.res"
 char *s = N_("Layer groups");
-# 430 "pcb-menu.res"
+# 436 "pcb-menu.res"
 char *s = N_("Left");
-# 437 "pcb-menu.res"
+# 443 "pcb-menu.res"
 char *s = N_("Library");
-# 168 "pcb-menu.res"
+# 174 "pcb-menu.res"
 char *s = N_("Line");
-# 391 "pcb-menu.res"
+# 397 "pcb-menu.res"
 char *s = N_("Line Tool size +");
-# 392 "pcb-menu.res"
+# 398 "pcb-menu.res"
 char *s = N_("Line Tool size -");
-# 251 "pcb-menu.res"
+# 257 "pcb-menu.res"
 char *s = N_("Lines +10 mil");
-# 250 "pcb-menu.res"
+# 256 "pcb-menu.res"
 char *s = N_("Lines -10 mil");
 # 38 "pcb-menu.res"
 char *s = N_("Load element data to paste-buffer");
@@ -530,151 +538,151 @@ char *s = N_("Load layout data to paste-buffer");
 char *s = N_("Load netlist file");
 # 41 "pcb-menu.res"
 char *s = N_("Load vendor resource file");
-# 182 "pcb-menu.res"
+# 188 "pcb-menu.res"
 char *s = N_("Lock");
 # 67 "pcb-menu.res"
 char *s = N_("Lock Names");
-# 301 "pcb-menu.res"
+# 307 "pcb-menu.res"
 char *s = N_("Lookup connection to object");
-# 393 "pcb-menu.res"
+# 399 "pcb-menu.res"
 char *s = N_("M");
-# 394 "pcb-menu.res"
+# 400 "pcb-menu.res"
 char *s = N_("MarkCrosshair");
-# 438 "pcb-menu.res"
+# 444 "pcb-menu.res"
 char *s = N_("Message Log");
-# 284 "pcb-menu.res"
+# 290 "pcb-menu.res"
 char *s = N_("Mirror buffer (left/right)");
-# 283 "pcb-menu.res"
+# 289 "pcb-menu.res"
 char *s = N_("Mirror buffer (up/down)");
-# 322 "pcb-menu.res"
+# 328 "pcb-menu.res"
 char *s = N_("Miter");
-# 180 "pcb-menu.res"
+# 186 "pcb-menu.res"
 char *s = N_("Move");
-# 393 "pcb-menu.res"
+# 399 "pcb-menu.res"
 char *s = N_("Move Object to current layer");
 # 130 "pcb-menu.res"
 char *s = N_("Move current layer down");
 # 129 "pcb-menu.res"
 char *s = N_("Move current layer up");
-# 240 "pcb-menu.res"
+# 246 "pcb-menu.res"
 char *s = N_("Move selected elements to other side");
-# 241 "pcb-menu.res"
+# 247 "pcb-menu.res"
 char *s = N_("Move selected to current layer");
 # 150 "pcb-menu.res"
 char *s = N_("N");
-# 439 "pcb-menu.res"
+# 445 "pcb-menu.res"
 char *s = N_("Netlist");
-# 212 "pcb-menu.res"
+# 218 "pcb-menu.res"
 char *s = N_("New elements added at...");
-# 201 "pcb-menu.res"
+# 207 "pcb-menu.res"
 char *s = N_("New lines, arcs clear polygons");
-# 202 "pcb-menu.res"
+# 208 "pcb-menu.res"
 char *s = N_("New polygons are full ones");
 # 98 "pcb-menu.res"
 char *s = N_("No Grid");
-# 166 "pcb-menu.res"
+# 172 "pcb-menu.res"
 char *s = N_("None");
-# 307 "pcb-menu.res"
+# 313 "pcb-menu.res"
 char *s = N_("O");
 # 68 "pcb-menu.res"
 char *s = N_("Only Names");
-# 329 "pcb-menu.res"
+# 335 "pcb-menu.res"
 char *s = N_("Only autorouted nets");
 # 72 "pcb-menu.res"
 char *s = N_("Open pinout menu");
-# 306 "pcb-menu.res"
+# 312 "pcb-menu.res"
 char *s = N_("Optimize rats-nest");
-# 245 "pcb-menu.res"
+# 251 "pcb-menu.res"
 char *s = N_("Optimize selected rats");
-# 193 "pcb-menu.res"
+# 199 "pcb-menu.res"
 char *s = N_("Orthogonal moves");
-# 320 "pcb-menu.res"
+# 326 "pcb-menu.res"
 char *s = N_("Orthopull");
-# 403 "pcb-menu.res"
+# 409 "pcb-menu.res"
 char *s = N_("P");
-# 233 "pcb-menu.res"
+# 239 "pcb-menu.res"
 char *s = N_("Pads");
-# 253 "pcb-menu.res"
+# 259 "pcb-menu.res"
 char *s = N_("Pads +10 mil");
-# 252 "pcb-menu.res"
+# 258 "pcb-menu.res"
 char *s = N_("Pads -10 mil");
-# 277 "pcb-menu.res"
+# 283 "pcb-menu.res"
 char *s = N_("Paste buffer to layout");
-# 440 "pcb-menu.res"
+# 446 "pcb-menu.res"
 char *s = N_("Pinout");
-# 208 "pcb-menu.res"
+# 214 "pcb-menu.res"
 char *s = N_("Pinout shows number");
-# 269 "pcb-menu.res"
+# 275 "pcb-menu.res"
 char *s = N_("Pins");
-# 265 "pcb-menu.res"
+# 271 "pcb-menu.res"
 char *s = N_("Pins +10 mil");
-# 264 "pcb-menu.res"
+# 270 "pcb-menu.res"
 char *s = N_("Pins -10 mil");
-# 209 "pcb-menu.res"
+# 215 "pcb-menu.res"
 char *s = N_("Pins/Via show Name/Number");
-# 172 "pcb-menu.res"
+# 178 "pcb-menu.res"
 char *s = N_("Polygon");
-# 404 "pcb-menu.res"
+# 410 "pcb-menu.res"
 char *s = N_("Polygon Close");
-# 173 "pcb-menu.res"
+# 179 "pcb-menu.res"
 char *s = N_("Polygon Hole");
-# 403 "pcb-menu.res"
+# 409 "pcb-menu.res"
 char *s = N_("Polygon PreviousPoint");
 # 42 "pcb-menu.res"
 char *s = N_("Print layout...");
-# 323 "pcb-menu.res"
+# 329 "pcb-menu.res"
 char *s = N_("Puller");
-# 405 "pcb-menu.res"
+# 411 "pcb-menu.res"
 char *s = N_("Q");
 # 53 "pcb-menu.res"
 char *s = N_("Quit Program");
-# 340 "pcb-menu.res"
+# 346 "pcb-menu.res"
 char *s = N_("R");
 # 97 "pcb-menu.res"
 char *s = N_("Realign grid");
-# 171 "pcb-menu.res"
+# 177 "pcb-menu.res"
 char *s = N_("Rectangle");
 # 135 "pcb-menu.res"
 char *s = N_("Redo last undone operation");
 # 65 "pcb-menu.res"
 char *s = N_("Reference Designator");
-# 342 "pcb-menu.res"
+# 348 "pcb-menu.res"
 char *s = N_("Remove");
-# 362 "pcb-menu.res"
+# 368 "pcb-menu.res"
 char *s = N_("Remove Connected");
-# 339 "pcb-menu.res"
+# 345 "pcb-menu.res"
 char *s = N_("Report found pins/pads");
-# 340 "pcb-menu.res"
+# 346 "pcb-menu.res"
 char *s = N_("Report net length");
-# 199 "pcb-menu.res"
+# 205 "pcb-menu.res"
 char *s = N_("Require unique element names");
-# 304 "pcb-menu.res"
+# 310 "pcb-menu.res"
 char *s = N_("Reset all connections");
-# 303 "pcb-menu.res"
+# 309 "pcb-menu.res"
 char *s = N_("Reset scanned lines/polygons");
-# 302 "pcb-menu.res"
+# 308 "pcb-menu.res"
 char *s = N_("Reset scanned pads/pins/vias");
 # 35 "pcb-menu.res"
 char *s = N_("Revert");
-# 431 "pcb-menu.res"
+# 437 "pcb-menu.res"
 char *s = N_("Right");
-# 313 "pcb-menu.res"
+# 319 "pcb-menu.res"
 char *s = N_("Rip up all auto-routed tracks");
-# 247 "pcb-menu.res"
+# 253 "pcb-menu.res"
 char *s = N_("Rip up selected auto-routed tracks");
-# 176 "pcb-menu.res"
+# 182 "pcb-menu.res"
 char *s = N_("Rotate");
-# 279 "pcb-menu.res"
+# 285 "pcb-menu.res"
 char *s = N_("Rotate buffer 90 deg CCW");
-# 281 "pcb-menu.res"
+# 287 "pcb-menu.res"
 char *s = N_("Rotate buffer 90 deg CW");
 # 159 "pcb-menu.res"
 char *s = N_("Route Styles");
-# 198 "pcb-menu.res"
+# 204 "pcb-menu.res"
 char *s = N_("Rubber band mode");
-# 406 "pcb-menu.res"
+# 412 "pcb-menu.res"
 char *s = N_("S");
-# 290 "pcb-menu.res"
+# 296 "pcb-menu.res"
 char *s = N_("Save buffer elements to file");
 # 46 "pcb-menu.res"
 char *s = N_("Save connection data of...");
@@ -682,273 +690,283 @@ char *s = N_("Save connection data of...");
 char *s = N_("Save layout");
 # 34 "pcb-menu.res"
 char *s = N_("Save layout as...");
-# 224 "pcb-menu.res"
+# 230 "pcb-menu.res"
 char *s = N_("Select all connected objects");
-# 223 "pcb-menu.res"
+# 229 "pcb-menu.res"
 char *s = N_("Select all found objects");
 # 147 "pcb-menu.res"
 char *s = N_("Select all visible");
-# 222 "pcb-menu.res"
+# 228 "pcb-menu.res"
 char *s = N_("Select all visible objects");
-# 230 "pcb-menu.res"
+# 236 "pcb-menu.res"
 char *s = N_("Select by name");
-# 292 "pcb-menu.res"
+# 298 "pcb-menu.res"
 char *s = N_("Select current buffer");
-# 395 "pcb-menu.res"
+# 401 "pcb-menu.res"
 char *s = N_("Select shortest rat");
-# 325 "pcb-menu.res"
+# 331 "pcb-menu.res"
 char *s = N_("Selected");
-# 217 "pcb-menu.res"
+# 223 "pcb-menu.res"
 char *s = N_("Set Dispersion");
-# 379 "pcb-menu.res"
+# 385 "pcb-menu.res"
 char *s = N_("Set Same");
 # 146 "pcb-menu.res"
 char *s = N_("Shift Alt<Key>a");
 # 34 "pcb-menu.res"
 char *s = N_("Shift Ctrl-S");
-# 390 "pcb-menu.res"
+# 396 "pcb-menu.res"
 char *s = N_("Shift Ctrl<Key>k");
 # 34 "pcb-menu.res"
 char *s = N_("Shift Ctrl<Key>s");
 # 136 "pcb-menu.res"
 char *s = N_("Shift Ctrl<Key>u");
-# 413 "pcb-menu.res"
+# 419 "pcb-menu.res"
 char *s = N_("Shift Ctrl<Key>v");
-# 293 "pcb-menu.res"
+# 299 "pcb-menu.res"
 char *s = N_("Shift-1");
-# 294 "pcb-menu.res"
+# 300 "pcb-menu.res"
 char *s = N_("Shift-2");
-# 295 "pcb-menu.res"
+# 301 "pcb-menu.res"
 char *s = N_("Shift-3");
-# 296 "pcb-menu.res"
+# 302 "pcb-menu.res"
 char *s = N_("Shift-4");
-# 297 "pcb-menu.res"
+# 303 "pcb-menu.res"
 char *s = N_("Shift-5");
-# 315 "pcb-menu.res"
+# 321 "pcb-menu.res"
 char *s = N_("Shift-=");
 # 146 "pcb-menu.res"
 char *s = N_("Shift-Alt-A");
-# 240 "pcb-menu.res"
+# 246 "pcb-menu.res"
 char *s = N_("Shift-B");
-# 345 "pcb-menu.res"
+# 351 "pcb-menu.res"
 char *s = N_("Shift-Backspace");
-# 390 "pcb-menu.res"
+# 396 "pcb-menu.res"
 char *s = N_("Shift-Ctrl-K");
 # 136 "pcb-menu.res"
 char *s = N_("Shift-Ctrl-U");
-# 413 "pcb-menu.res"
+# 419 "pcb-menu.res"
 char *s = N_("Shift-Ctrl-V");
-# 440 "pcb-menu.res"
+# 446 "pcb-menu.res"
 char *s = N_("Shift-D");
-# 362 "pcb-menu.res"
+# 368 "pcb-menu.res"
 char *s = N_("Shift-Delete");
-# 309 "pcb-menu.res"
+# 315 "pcb-menu.res"
 char *s = N_("Shift-E");
-# 304 "pcb-menu.res"
+# 310 "pcb-menu.res"
 char *s = N_("Shift-F");
-# 280 "pcb-menu.res"
+# 286 "pcb-menu.res"
 char *s = N_("Shift-F7");
 # 115 "pcb-menu.res"
 char *s = N_("Shift-G");
-# 383 "pcb-menu.res"
+# 389 "pcb-menu.res"
 char *s = N_("Shift-H");
-# 386 "pcb-menu.res"
-char *s = N_("Shift-J");
-# 388 "pcb-menu.res"
-char *s = N_("Shift-K");
 # 392 "pcb-menu.res"
+char *s = N_("Shift-J");
+# 394 "pcb-menu.res"
+char *s = N_("Shift-K");
+# 398 "pcb-menu.res"
 char *s = N_("Shift-L");
-# 241 "pcb-menu.res"
+# 247 "pcb-menu.res"
 char *s = N_("Shift-M");
-# 395 "pcb-menu.res"
+# 401 "pcb-menu.res"
 char *s = N_("Shift-N");
-# 396 "pcb-menu.res"
+# 402 "pcb-menu.res"
 char *s = N_("Shift-O");
-# 404 "pcb-menu.res"
+# 410 "pcb-menu.res"
 char *s = N_("Shift-P");
 # 135 "pcb-menu.res"
 char *s = N_("Shift-R");
-# 407 "pcb-menu.res"
+# 413 "pcb-menu.res"
 char *s = N_("Shift-S");
-# 411 "pcb-menu.res"
+# 417 "pcb-menu.res"
 char *s = N_("Shift-T");
 # 57 "pcb-menu.res"
 char *s = N_("Shift-Tab");
-# 412 "pcb-menu.res"
+# 418 "pcb-menu.res"
 char *s = N_("Shift-V");
-# 416 "pcb-menu.res"
+# 422 "pcb-menu.res"
 char *s = N_("Shift-W");
 # 80 "pcb-menu.res"
 char *s = N_("Shift-Z");
-# 293 "pcb-menu.res"
+# 299 "pcb-menu.res"
 char *s = N_("Shift<Key>1");
-# 294 "pcb-menu.res"
+# 300 "pcb-menu.res"
 char *s = N_("Shift<Key>2");
-# 295 "pcb-menu.res"
+# 301 "pcb-menu.res"
 char *s = N_("Shift<Key>3");
-# 296 "pcb-menu.res"
+# 302 "pcb-menu.res"
 char *s = N_("Shift<Key>4");
-# 297 "pcb-menu.res"
+# 303 "pcb-menu.res"
 char *s = N_("Shift<Key>5");
-# 315 "pcb-menu.res"
+# 321 "pcb-menu.res"
 char *s = N_("Shift<Key>=");
-# 345 "pcb-menu.res"
+# 351 "pcb-menu.res"
 char *s = N_("Shift<Key>BackSpace");
-# 362 "pcb-menu.res"
+# 368 "pcb-menu.res"
 char *s = N_("Shift<Key>Delete");
-# 429 "pcb-menu.res"
+# 435 "pcb-menu.res"
 char *s = N_("Shift<Key>Down");
-# 280 "pcb-menu.res"
+# 286 "pcb-menu.res"
 char *s = N_("Shift<Key>F7");
-# 430 "pcb-menu.res"
+# 436 "pcb-menu.res"
 char *s = N_("Shift<Key>Left");
-# 431 "pcb-menu.res"
+# 437 "pcb-menu.res"
 char *s = N_("Shift<Key>Right");
 # 57 "pcb-menu.res"
 char *s = N_("Shift<Key>Tab");
-# 428 "pcb-menu.res"
+# 434 "pcb-menu.res"
 char *s = N_("Shift<Key>Up");
-# 240 "pcb-menu.res"
+# 246 "pcb-menu.res"
 char *s = N_("Shift<Key>b");
-# 440 "pcb-menu.res"
+# 446 "pcb-menu.res"
 char *s = N_("Shift<Key>d");
-# 309 "pcb-menu.res"
+# 315 "pcb-menu.res"
 char *s = N_("Shift<Key>e");
-# 304 "pcb-menu.res"
+# 310 "pcb-menu.res"
 char *s = N_("Shift<Key>f");
 # 115 "pcb-menu.res"
 char *s = N_("Shift<Key>g");
-# 383 "pcb-menu.res"
+# 389 "pcb-menu.res"
 char *s = N_("Shift<Key>h");
-# 386 "pcb-menu.res"
-char *s = N_("Shift<Key>j");
-# 388 "pcb-menu.res"
-char *s = N_("Shift<Key>k");
 # 392 "pcb-menu.res"
+char *s = N_("Shift<Key>j");
+# 394 "pcb-menu.res"
+char *s = N_("Shift<Key>k");
+# 398 "pcb-menu.res"
 char *s = N_("Shift<Key>l");
-# 241 "pcb-menu.res"
+# 247 "pcb-menu.res"
 char *s = N_("Shift<Key>m");
-# 395 "pcb-menu.res"
+# 401 "pcb-menu.res"
 char *s = N_("Shift<Key>n");
-# 396 "pcb-menu.res"
+# 402 "pcb-menu.res"
 char *s = N_("Shift<Key>o");
-# 404 "pcb-menu.res"
+# 410 "pcb-menu.res"
 char *s = N_("Shift<Key>p");
 # 135 "pcb-menu.res"
 char *s = N_("Shift<Key>r");
-# 407 "pcb-menu.res"
+# 413 "pcb-menu.res"
 char *s = N_("Shift<Key>s");
-# 411 "pcb-menu.res"
+# 417 "pcb-menu.res"
 char *s = N_("Shift<Key>t");
-# 412 "pcb-menu.res"
+# 418 "pcb-menu.res"
 char *s = N_("Shift<Key>v");
-# 416 "pcb-menu.res"
+# 422 "pcb-menu.res"
 char *s = N_("Shift<Key>w");
 # 80 "pcb-menu.res"
 char *s = N_("Shift<Key>z");
-# 203 "pcb-menu.res"
+# 209 "pcb-menu.res"
 char *s = N_("Show autorouter trials");
 # 61 "pcb-menu.res"
 char *s = N_("Show soldermask");
 # 119 "pcb-menu.res"
 char *s = N_("Shown Layers");
-# 321 "pcb-menu.res"
+# 327 "pcb-menu.res"
 char *s = N_("SimpleOpts");
-# 420 "pcb-menu.res"
+# 426 "pcb-menu.res"
 char *s = N_("Space");
 # 58 "pcb-menu.res"
 char *s = N_("Spin 180");
 # 51 "pcb-menu.res"
 char *s = N_("Start new layout");
-# 429 "pcb-menu.res"
+# 435 "pcb-menu.res"
 char *s = N_("Step +Down");
-# 430 "pcb-menu.res"
+# 436 "pcb-menu.res"
 char *s = N_("Step +Left");
-# 431 "pcb-menu.res"
+# 437 "pcb-menu.res"
 char *s = N_("Step +Right");
-# 428 "pcb-menu.res"
+# 434 "pcb-menu.res"
 char *s = N_("Step +Up");
-# 425 "pcb-menu.res"
+# 431 "pcb-menu.res"
 char *s = N_("Step Down");
-# 426 "pcb-menu.res"
+# 432 "pcb-menu.res"
 char *s = N_("Step Left");
-# 427 "pcb-menu.res"
+# 433 "pcb-menu.res"
 char *s = N_("Step Right");
-# 424 "pcb-menu.res"
+# 430 "pcb-menu.res"
 char *s = N_("Step Up");
 # 59 "pcb-menu.res"
 char *s = N_("Swap Sides");
-# 410 "pcb-menu.res"
+# 416 "pcb-menu.res"
 char *s = N_("T");
 # 56 "pcb-menu.res"
 char *s = N_("Tab");
-# 422 "pcb-menu.res"
+# 428 "pcb-menu.res"
 char *s = N_("Temp Arrow OFF");
-# 421 "pcb-menu.res"
+# 427 "pcb-menu.res"
 char *s = N_("Temp Arrow ON");
-# 170 "pcb-menu.res"
+# 176 "pcb-menu.res"
 char *s = N_("Text");
-# 235 "pcb-menu.res"
+# 241 "pcb-menu.res"
 char *s = N_("Text Objects");
-# 410 "pcb-menu.res"
+# 416 "pcb-menu.res"
 char *s = N_("Text Tool scale +10 mil");
-# 411 "pcb-menu.res"
+# 417 "pcb-menu.res"
 char *s = N_("Text Tool scale -10 mil");
-# 257 "pcb-menu.res"
+# 263 "pcb-menu.res"
 char *s = N_("Texts +10 mil");
-# 256 "pcb-menu.res"
+# 262 "pcb-menu.res"
 char *s = N_("Texts -10 mil");
-# 177 "pcb-menu.res"
+# 183 "pcb-menu.res"
 char *s = N_("Thermal");
-# 204 "pcb-menu.res"
+# 210 "pcb-menu.res"
 char *s = N_("Thin draw");
-# 205 "pcb-menu.res"
+# 211 "pcb-menu.res"
 char *s = N_("Thin draw poly");
-# 382 "pcb-menu.res"
+# 166 "pcb-menu.res"
+char *s = N_("Through-hole");
+# 388 "pcb-menu.res"
 char *s = N_("ToggleHideName Object");
-# 383 "pcb-menu.res"
+# 389 "pcb-menu.res"
 char *s = N_("ToggleHideName SelectedElement");
 # 134 "pcb-menu.res"
 char *s = N_("U");
-# 418 "pcb-menu.res"
+# 424 "pcb-menu.res"
 char *s = N_("Undo");
 # 134 "pcb-menu.res"
 char *s = N_("Undo last operation");
-# 317 "pcb-menu.res"
+# 323 "pcb-menu.res"
 char *s = N_("Unjaggy");
 # 146 "pcb-menu.res"
 char *s = N_("Unselect all");
-# 226 "pcb-menu.res"
+# 232 "pcb-menu.res"
 char *s = N_("Unselect all objects");
-# 428 "pcb-menu.res"
+# 434 "pcb-menu.res"
 char *s = N_("Up");
 # 82 "pcb-menu.res"
 char *s = N_("V");
 # 66 "pcb-menu.res"
 char *s = N_("Value");
-# 167 "pcb-menu.res"
+# 173 "pcb-menu.res"
 char *s = N_("Via");
-# 414 "pcb-menu.res"
+# 420 "pcb-menu.res"
 char *s = N_("Via Tool drill +5 mil");
-# 415 "pcb-menu.res"
+# 421 "pcb-menu.res"
 char *s = N_("Via Tool drill -5 mil");
-# 412 "pcb-menu.res"
+# 418 "pcb-menu.res"
 char *s = N_("Via Tool size +5 mil");
-# 413 "pcb-menu.res"
+# 419 "pcb-menu.res"
 char *s = N_("Via Tool size -5 mil");
-# 318 "pcb-menu.res"
+# 165 "pcb-menu.res"
+char *s = N_("Via type");
+# 324 "pcb-menu.res"
 char *s = N_("Vianudge");
-# 236 "pcb-menu.res"
+# 242 "pcb-menu.res"
 char *s = N_("Vias");
-# 263 "pcb-menu.res"
+# 269 "pcb-menu.res"
 char *s = N_("Vias +10 mil");
-# 262 "pcb-menu.res"
+# 268 "pcb-menu.res"
 char *s = N_("Vias -10 mil");
-# 319 "pcb-menu.res"
+# 325 "pcb-menu.res"
 char *s = N_("Viatrim");
-# 417 "pcb-menu.res"
+# 423 "pcb-menu.res"
 char *s = N_("W");
-# 323 "pcb-menu.res"
+# 167 "pcb-menu.res"
+char *s = N_("Xtrl-Shift-F");
+# 166 "pcb-menu.res"
+char *s = N_("Xtrl-Shift-P");
+# 168 "pcb-menu.res"
+char *s = N_("Xtrl-Shift-T");
+# 329 "pcb-menu.res"
 char *s = N_("Y");
 # 79 "pcb-menu.res"
 char *s = N_("Z");
@@ -980,9 +998,9 @@ char *s = N_("Zoom to 10mil/px");
 char *s = N_("Zoom to 1mil/px");
 # 89 "pcb-menu.res"
 char *s = N_("Zoom to 2.5mil/px");
-# 421 "pcb-menu.res"
+# 427 "pcb-menu.res"
 char *s = N_("[");
-# 422 "pcb-menu.res"
+# 428 "pcb-menu.res"
 char *s = N_("]");
 # 83 "pcb-menu.res"
 char *s = N_("`");
@@ -990,9 +1008,9 @@ char *s = N_("`");
 char *s = N_("mil");
 # 95 "pcb-menu.res"
 char *s = N_("mm");
-# 228 "pcb-menu.res"
+# 234 "pcb-menu.res"
 char *s = N_("unselect all connected objects");
-# 227 "pcb-menu.res"
+# 233 "pcb-menu.res"
 char *s = N_("unselect all found objects");
-# 204 "pcb-menu.res"
+# 210 "pcb-menu.res"
 char *s = N_("|");
